@@ -10,7 +10,7 @@ from xmli.libs.shared import create_node, enc_in
 
 class xml(object):
 	"""
-	xml(path: str) -> xml
+	xml(path: str, create_only: bool = False) -> xml
 
 	With this class you can read an XML file and update it with a simple, object-like interface.
 	When used in 'str()', returns (updated in real time) XML file code.
